# miniscope-io

(Demonstration project for a lab workshop on making modular, testable python code.
Functionality not guaranteed
-<3 jonny)



## Licensing

This package includes software sublicensed from more 
restrictive licenses. Those licenses can be found
in the `LICENSE` files in the respective directories 
containing the unmodified source material

* `miniscope_io/vendor/opalkelly`